@@ -2,11 +2,6 @@
 
 ; FIXME: do all of these really need to be here?
 
-(define FALSE 0)
-(define TRUE 1)
-(define NULL 0)
-(define EXPAND-FILL (+ GTK-EXPAND GTK-FILL))
-
 (define (launch-gnome fn)
   ; call to gtk-main moved to gnome-guile.c (federico)
   (fn)
@@ -15,10 +10,11 @@
 (define (gnome-internal-make-filled-box boxfunc homogeneous padding widgets)
   (let ((box (boxfunc homogeneous padding)))
     (for-each (lambda (widget)
-		(case (car (cddddr widget))
-		  ((start) (gtk-box-pack-start box (car widget) (cadr widget) (caddr widget) (cadddr widget)))
-		  ((end) (gtk-box-pack-end box (car widget) (cadr widget) (caddr widget) (cadddr widget))))
-		(gtk-widget-show (car widget)))
+		(if (not (null? widget))
+		    (case (car (cddddr widget))
+		      ((start) (gtk-box-pack-start box (car widget) (cadr widget) (caddr widget) (cadddr widget)))
+		      ((end) (gtk-box-pack-end box (car widget) (cadr widget) (caddr widget) (cadddr widget))))
+		    (gtk-widget-show (car widget))))
 	      widgets)
     (gtk-widget-show box)
     box))
