@@ -1,6 +1,8 @@
 #ifndef GNOME_CONFIG_H
 #define GNOME_CONFIG_H
 
+BEGIN_GNOME_DECLS
+
 /* Prototypes for the profile management functions */
 
 char *gnome_config_get_string    (char *path);
@@ -27,4 +29,6 @@ void gnome_config_clean_file     (char *path);
 /* This routine drops all of the information related to /file/section */
 void gnome_config_clean_section  (char *path);
 
+END_GNOME_DECLS
+
 #endif
