@@ -4,13 +4,13 @@
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <glib.h>
+#include <gtk/gtk.h>
 #include "libgnome/libgnome.h"
-
-char *gnome_user_home_dir = 0;
+#include "gnome-colors.h"
 
 void
 gnome_init (int *argc, char ***argv)
 {
 	gnomelib_init (argc, argv);
+	gnome_colors_init();
 }
