@@ -233,7 +233,7 @@ color_setup ()
 	gdk_color_parse (gnome_config_get_string ("/Desktop/Background/color2=rgb:00/00/ff"), &color2);
 	gnome_color_selector_set_color_int (cs2, color2.red, color2.green, color2.blue, 65535);
 
-	fill_monitor();
+	/* fill_monitor(); */
 
 	button2 = gnome_color_selector_get_button(cs2);
 	gtk_table_attach(GTK_TABLE(table), button2, 0, 1, 2, 4, 0, 0, 0, 0);
@@ -310,7 +310,7 @@ background_setup (GtkWidget *window)
 	GtkWidget *hbox;
 	GtkWidget *fill, *wallp;
 	
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_vbox_new (TRUE, 0);
 
 	hbox = gtk_hbox_new (TRUE, 0);
 	gtk_container_border_width (GTK_CONTAINER(hbox), 10);
@@ -318,13 +318,11 @@ background_setup (GtkWidget *window)
 	monitor = get_monitor_preview_widget (window);
 	
 	gtk_box_pack_start (GTK_BOX(hbox), monitor, FALSE, FALSE, 5);
-	gtk_widget_show (monitor);
 
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, 1, 1, 1);
-	gtk_widget_show(hbox);
 	
 	settings = gtk_hbox_new (TRUE, 0);
-	gtk_widget_show (settings);
+	gtk_container_border_width (GTK_CONTAINER(settings), 10);
 	gtk_box_pack_end (GTK_BOX (vbox), settings, 1, 1, 0);
 
 	fill = color_setup ();
@@ -333,6 +331,11 @@ background_setup (GtkWidget *window)
 	wallp  = wallpaper_setup ();
 	gtk_box_pack_end (GTK_BOX (settings), wallp, 1, 1, PAD);
 	
-	gtk_widget_show (vbox);
+	gtk_widget_show (monitor);
+	gtk_widget_show (settings);
+	gtk_widget_show (hbox);
+
         register_extension (gtk_label_new (_("Background")), vbox, background_action);
+
+	gtk_widget_show (vbox);
 }
